https://gcc.gnu.org/bugzilla/show_bug.cgi?id=127736
Bug ID: 127736
Summary: [17 Regression] 15% slowdown of SPEC 2006 milc on
aarch64 since r17-4808-ga9b19ded78ca2d
Product: gcc
Version: 17.0
Status: UNCONFIRMED
Keywords: missed-optimization
Severity: normal
Priority: P3
Component: tree-optimization
Assignee: unassigned at gcc dot gnu.org
Reporter: jmelcr at gcc dot gnu.org
CC: rguenth at gcc dot gnu.org
Blocks: 26163
Target Milestone: ---
Host: aarch64-suse-linux
Target: aarch64-suse-linux
Build: aarch64-suse-linux
I am seeing a 15% slowdown of SPEC 2006 milc on aarch64 (Neoverse N1) when
compiling with -O2 -march=native:
https://lnt.opensuse.org/db_default/v4/SPEC/graph?plot.0=580.70.0
The slowdown bisects to r17-4808-ga9b19ded78ca2d:
commit a9b19ded78ca2dd8f66b355b05ebbbb149c2d320
Author: Richard Biener <[email protected]>
Date: Thu Oct 1 09:21:30 2026 +0200
tree-optimization/127686 - mis-applied -O2 vector cost model heuristic
This is a regression against GCC 16:
https://lnt.opensuse.org/db_default/v4/SPEC/graph?plot.0=1042.70.0&plot.1=1224.70.0&plot.2=1521.70.0&plot.3=580.70.0&
The blamed commit is a fix for PR127686, sadly it did have fallout.
Referenced Bugs:
https://gcc.gnu.org/bugzilla/show_bug.cgi?id=26163
[Bug 26163] [meta-bug] missed optimization in SPEC (2026, 2k17, 2k and 2k6 and
95)